@@ -19,8 +19,8 @@ import gdb
 import os
 import os.path
 
-pythondir = '/builder/apm821xx_nand/build/staging_dir/toolchain-powerpc_464fp_gcc-7.3.0_musl/share/gcc-7.3.0/python'
-libdir = '/builder/apm821xx_nand/build/staging_dir/toolchain-powerpc_464fp_gcc-7.3.0_musl/powerpc-openwrt-linux-musl/lib'
+pythondir = '/builder/shared-workdir/build/staging_dir/toolchain-powerpc_464fp_gcc-7.3.0_musl/share/gcc-7.3.0/python'
+libdir = '/builder/shared-workdir/build/staging_dir/toolchain-powerpc_464fp_gcc-7.3.0_musl/powerpc-openwrt-linux-musl/lib'
 
 # This file might be loaded when there is no current objfile.  This
 # can happen if the user loads it manually.  In this case we don't
